@@ -1,55 +1,44 @@
 # -*- encoding: utf-8 -*-
+import datetime
 import decimal
 import struct
-import time
 import unittest
 
-from pamqp import decode, PYTHON3
-
-if PYTHON3:
-    long = int
-    unicode = None
-    basestring = (bytes, str)
+from pamqp import decode
 
 PLATFORM_32BIT = (struct.calcsize('P') * 8) == 32
 PLATFORM_64BIT = (struct.calcsize('P') * 8) == 64
 
 
-def _utf8_key(value):
-    return value.decode('utf-8') if not PYTHON3 else value
-
-
 class CodecDecodeTests(unittest.TestCase):
-    FIELD_ARR = (b'\x00\x00\x00@s\x00\x01I\x00\x00\xaf\xc8S\x00\x00'
-                 b'\x00\x08Test \xe2\x9c\x88T\x00\x00\x00\x00Ec)\x92'
-                 b'I\xbb\x9a\xca\x00D\x02\x00\x00\x01:f@H\xf5\xc3l'
-                 b'\x00\x00\x00\x00\xc4e5\xffl\x80\x00\x00\x00\x00'
-                 b'\x00\x00\x08')
+    FIELD_ARR = (b'\x00\x00\x009b\x01u\xaf\xc8S\x00\x00\x00\x08Test \xe2\x9c'
+                 b'\x88T\x00\x00\x00\x00Ec)\x92I\xbb\x9a\xca\x00D\x02\x00\x00'
+                 b'\x01:f@H\xf5\xc3i\xc4e5\xffl\x80\x00\x00\x00\x00\x00\x00'
+                 b'\x08')
     FIELD_ARR_VALUE = [
-        1, 45000, b'Test \xe2\x9c\x88',
-        time.struct_time((2006, 11, 21, 16, 30, 10, 1, 325, 0)), -1147483648,
+        1, 45000, 'Test ✈',
+        datetime.datetime(2006, 11, 21, 16, 30, 10), -1147483648,
         decimal.Decimal('3.14'), 3.14, 3294967295, -9223372036854775800
     ]
     FIELD_TBL = (
-        b'\x00\x00\x00\x9d\x08arrayvalA\x00\x00\x00\ts\x00\x01s\x00\x02s\x00'
-        b'\x03\x07boolvalt\x01\x06decvalD\x02\x00\x00\x01:\x07dictvalF\x00'
-        b'\x00\x00\r\x04f\xe2\x9c\x89S\x00\x00\x00\x03\xe2\x9c\x90\x08'
-        b'floatvalf@H\xf5\xc3\x06intvals\x00\x01\x07longvalI6e&U\x06strvalS'
-        b'\x00\x00\x00\x08Test \xe2\x9c\x88\x0ctimestampvalT\x00\x00\x00'
-        b'\x00Ec)\x92\x04\xf0\x9f\x90\xb0V'
+        b'\x00\x00\x00\x99\x08arrayvalA\x00\x00\x00\x06b\x01b\x02b\x03\x07'
+        b'boolvalt\x01\x06decvalD\x02\x00\x00\x01:\x07dictvalF\x00\x00\x00'
+        b'\r\x04f\xe2\x9c\x89S\x00\x00\x00\x03\xe2\x9c\x90\x08floatvalf@H'
+        b'\xf5\xc3\x06intvalb\x01\x07longvalI6e&U\x06strvalS\x00\x00\x00\x08'
+        b'Test \xe2\x9c\x88\x0ctimestampvalT\x00\x00\x00\x00Ec)\x92\x04\xf0'
+        b'\x9f\x90\xb0V'
     )
     FIELD_TBL_VALUE = {
         'intval': 1,
-        'strval': b'Test \xe2\x9c\x88',
+        'strval': 'Test ✈',
         'boolval': True,
-        'timestampval': time.struct_time(
-            (2006, 11, 21, 16, 30, 10, 1, 325, 0)),
+        'timestampval': datetime.datetime(2006, 11, 21, 16, 30, 10),
         'decval': decimal.Decimal('3.14'),
-        _utf8_key('🐰'): None,
+        '🐰': None,
         'floatval': 3.14,
-        'longval': long(912598613),
+        'longval': 912598613,
         'dictval': {
-            _utf8_key('f✉'): b'\xe2\x9c\x90'
+            'f✉': '✐'
         },
         'arrayval': [1, 2, 3]
     }
@@ -119,10 +108,10 @@ class CodecDecodeTests(unittest.TestCase):
         self.assertRaises(ValueError, decode.double, 123)
 
     def test_decode_embedded_value_null(self):
-        self.assertEqual(decode._embedded_value(b'\00')[1], None)
+        self.assertEqual(decode.embedded_value(b'\00')[1], None)
 
     def test_decode_embedded_value_invalid_data(self):
-        self.assertRaises(ValueError, decode._embedded_value, b'Z\x00')
+        self.assertRaises(ValueError, decode.embedded_value, b'Z\x00')
 
     def test_decode_floating_point_bytes_consumed(self):
         value = b'@I\x0f\xd0'
@@ -167,7 +156,7 @@ class CodecDecodeTests(unittest.TestCase):
     @unittest.skipIf(PLATFORM_64BIT, 'Skipped on 64-bit platforms')
     def test_decode_long_long_int_data_type_32bit(self):
         value = b'\x7f\xff\xff\xff\xff\xff\xff\xf8'
-        self.assertIsInstance(decode.long_long_int(value)[1], long)
+        self.assertIsInstance(decode.long_long_int(value)[1], int)
 
     def test_decode_long_long_int_invalid_value(self):
         self.assertRaises(ValueError, decode.long_long_int, None)
@@ -182,20 +171,20 @@ class CodecDecodeTests(unittest.TestCase):
 
     def test_decode_long_str_data_type(self):
         value = b'\x00\x00\x00\n0123456789'
-        self.assertIsInstance(decode.long_str(value)[1], basestring)
+        self.assertIsInstance(decode.long_str(value)[1], str)
 
     def test_decode_long_str_data_type_unicode(self):
         self.assertIsInstance(
             decode.long_str(b'\x00\x00\x00\x0c\xd8\xa7'
                             b'\xd8\xae\xd8\xaa\xd8\xa8'
-                            b'\xd8\xa7\xd8\xb1')[1], bytes)
+                            b'\xd8\xa7\xd8\xb1')[1], str)
 
     def test_decode_long_str_invalid_value(self):
         self.assertRaises(ValueError, decode.long_str, None)
 
     def test_decode_long_str_value(self):
         value = b'\x00\x00\x00\n0123456789'
-        self.assertEqual(decode.long_str(value)[1], b'0123456789')
+        self.assertEqual(decode.long_str(value)[1], '0123456789')
 
     def test_decode_octet_bytes_consumed(self):
         value = b'\xff'
@@ -233,14 +222,17 @@ class CodecDecodeTests(unittest.TestCase):
     def test_decode_short_short_int_invalid_value(self):
         self.assertRaises(ValueError, decode.short_short_int, None)
 
-    def test_decode_short_short_int_value(self):
-        self.assertEqual(decode.short_short_int(b'\xff')[1], 255)
+    def test_decode_short_short_uint_value(self):
+        self.assertEqual(decode.short_short_uint(b'\xff')[1], 255)
+
+    def test_decode_short_short_uint_invalid_value(self):
+        self.assertRaises(ValueError, decode.short_short_uint, None)
 
     def test_decode_short_str_bytes_consumed(self):
         self.assertEqual(decode.short_str(b'\n0123456789')[0], 11)
 
     def test_decode_short_str_data_type(self):
-        self.assertIsInstance(decode.short_str(b'\n0123456789')[1], basestring)
+        self.assertIsInstance(decode.short_str(b'\n0123456789')[1], str)
 
     def test_decode_short_str_invalid_value(self):
         self.assertRaises(ValueError, decode.short_str, None)
@@ -253,7 +245,7 @@ class CodecDecodeTests(unittest.TestCase):
 
     def test_decode_timestamp_data_type(self):
         self.assertIsInstance(
-            decode.timestamp(b'\x00\x00\x00\x00Ec)\x92')[1], time.struct_time)
+            decode.timestamp(b'\x00\x00\x00\x00Ec)\x92')[1], datetime.datetime)
 
     def test_decode_timestamp_invalid_value(self):
         self.assertRaises(ValueError, decode.timestamp, None)
@@ -261,7 +253,7 @@ class CodecDecodeTests(unittest.TestCase):
     def test_decode_timestamp_value(self):
         self.assertEqual(
             decode.timestamp(b'\x00\x00\x00\x00Ec)\x92')[1],
-            time.struct_time((2006, 11, 21, 16, 30, 10, 1, 325, 0)))
+            datetime.datetime(2006, 11, 21, 16, 30, 10))
 
     def test_decode_field_array_bytes_consumed(self):
         self.assertEqual(
@@ -413,7 +405,7 @@ class CodecDecodeTests(unittest.TestCase):
     @unittest.skipIf(PLATFORM_64BIT, 'Skipped on 64-bit platforms')
     def test_decode_by_type_long_long_data_type_32bit(self):
         value = b'\x7f\xff\xff\xff\xff\xff\xff\xf8'
-        self.assertIsInstance(decode.by_type(value, 'longlong')[1], long)
+        self.assertIsInstance(decode.by_type(value, 'longlong')[1], int)
 
     @unittest.skipIf(PLATFORM_32BIT, 'Skipped on 32-bit platforms')
     def test_decode_by_type_long_long_data_type_64bit(self):
@@ -434,18 +426,18 @@ class CodecDecodeTests(unittest.TestCase):
 
     def test_decode_by_type_longstr_data_type_with_unicode(self):
         value = b'\x00\x00\x00\x08Test \xe2\x9c\x88'
-        self.assertIsInstance(decode.by_type(value, 'longstr')[1], bytes)
+        self.assertIsInstance(decode.by_type(value, 'longstr')[1], str)
 
     def test_decode_by_type_longstr_data_type(self):
         value = b'\x00\x00\x00\n0123456789'
-        self.assertIsInstance(decode.by_type(value, 'longstr')[1], basestring)
+        self.assertIsInstance(decode.by_type(value, 'longstr')[1], str)
 
     def test_decode_by_type_longstr_invalid_value(self):
         self.assertRaises(ValueError, decode.by_type, None, 'longstr')
 
     def test_decode_by_type_longstr_value(self):
         value = b'\x00\x00\x00\n0123456789'
-        self.assertEqual(decode.by_type(value, 'longstr')[1], b'0123456789')
+        self.assertEqual(decode.by_type(value, 'longstr')[1], '0123456789')
 
     def test_decode_by_type_octet_bytes_consumed(self):
         self.assertEqual(decode.by_type(b'\xff', 'octet')[0], 1)
@@ -481,7 +473,7 @@ class CodecDecodeTests(unittest.TestCase):
     def test_decode_by_type_timestamp_data_type(self):
         value = b'\x00\x00\x00\x00Ec)\x92'
         self.assertIsInstance(
-            decode.by_type(value, 'timestamp')[1], time.struct_time)
+            decode.by_type(value, 'timestamp')[1], datetime.datetime)
 
     def test_decode_by_type_timestamp_invalid_value(self):
         self.assertRaises(ValueError, decode.by_type, None, 'timestamp')
@@ -490,10 +482,10 @@ class CodecDecodeTests(unittest.TestCase):
         value = b'\x00\x00\x00\x00Ec)\x92'
         self.assertEqual(
             decode.by_type(value, 'timestamp')[1],
-            time.struct_time((2006, 11, 21, 16, 30, 10, 1, 325, 0)))
+            datetime.datetime(2006, 11, 21, 16, 30, 10))
 
     def test_decode_by_type_void(self):
-        self.assertIsNone(decode.by_type(b'', 'void'))
+        self.assertIsNone(decode.by_type(b'', 'void')[1])
 
     def test_decode_by_type_field_array_bytes_consumed(self):
         self.assertEqual(
@@ -513,8 +505,8 @@ class CodecDecodeTests(unittest.TestCase):
                     round(value[position], 3),
                     round(self.FIELD_ARR_VALUE[position], 3))
             else:
-                self.assertEqual(value[position],
-                                 self.FIELD_ARR_VALUE[position])
+                self.assertEqual(
+                    value[position], self.FIELD_ARR_VALUE[position])
 
     def test_decode_by_type_field_table_bytes_consumed(self):
         self.assertEqual(
@@ -530,164 +522,163 @@ class CodecDecodeTests(unittest.TestCase):
         value = decode.by_type(self.FIELD_TBL, 'table')[1]
         for key in self.FIELD_TBL_VALUE.keys():
             if isinstance(value[key], float):
-                self.assertAlmostEqual(round(value[key], 3),
-                                       round(self.FIELD_TBL_VALUE[key], 3))
+                self.assertAlmostEqual(
+                    round(value[key], 3), round(self.FIELD_TBL_VALUE[key], 3))
             else:
                 self.assertEqual(value[key], self.FIELD_TBL_VALUE[key])
 
     def test_decode_embedded_value_empty_bytes_consumed(self):
-        self.assertEqual(decode._embedded_value(b'')[0], 0)
+        self.assertEqual(decode.embedded_value(b'')[0], 0)
 
     def test_decode_embedded_value_empty_value(self):
-        self.assertEqual(decode._embedded_value(b'')[1], None)
+        self.assertEqual(decode.embedded_value(b'')[1], None)
 
     def test_decode_embedded_value_decimal_bytes_consumed(self):
         value = b'D\x05\x00\x04\xcb/'
-        self.assertEqual(decode._embedded_value(value)[0], len(value))
+        self.assertEqual(decode.embedded_value(value)[0], len(value))
 
     def test_decode_embedded_value_decimal_data_type(self):
         value = b'D\x05\x00\x04\xcb/'
         self.assertIsInstance(
-            decode._embedded_value(value)[1], decimal.Decimal)
+            decode.embedded_value(value)[1], decimal.Decimal)
 
     def test_decode_embedded_value_decimal_value(self):
         value = b'D\x05\x00\x04\xcb/'
-        self.assertEqual(round(float(decode._embedded_value(value)[1]), 5),
+        self.assertEqual(round(float(decode.embedded_value(value)[1]), 5),
                          round(float(decimal.Decimal('3.14159')), 5))
 
     def test_decode_embedded_value_double_bytes_consumed(self):
         value = b'dC\x0f\xd8\x91\x14\xb9\xc3\x98'
-        self.assertEqual(decode._embedded_value(value)[0], len(value))
+        self.assertEqual(decode.embedded_value(value)[0], len(value))
 
     def test_decode_embedded_value_double_data_type(self):
         value = b'dC\x0f\xd8\x91\x14\xb9\xc3\x98'
-        self.assertIsInstance(decode._embedded_value(value)[1], float)
+        self.assertIsInstance(decode.embedded_value(value)[1], float)
 
     def test_decode_embedded_value_double_value(self):
         value = b'dC\x0f\xd8\x91\x14\xb9\xc3\x98'
-        self.assertEqual(decode._embedded_value(value)[1], 1120480238450803.0)
+        self.assertEqual(decode.embedded_value(value)[1], 1120480238450803.0)
 
     def test_decode_embedded_value_long_bytes_consumed(self):
         value = b'I\x7f\xff\xff\xff'
-        self.assertEqual(decode._embedded_value(value)[0], 5)
+        self.assertEqual(decode.embedded_value(value)[0], 5)
 
     def test_decode_embedded_value_long_data_type(self):
         value = b'I\x7f\xff\xff\xff'
-        self.assertIsInstance(decode._embedded_value(value)[1], int)
+        self.assertIsInstance(decode.embedded_value(value)[1], int)
 
     def test_decode_embedded_value_long_value(self):
         value = b'I\x7f\xff\xff\xff'
-        self.assertEqual(decode._embedded_value(value)[1], 2147483647)
+        self.assertEqual(decode.embedded_value(value)[1], 2147483647)
 
     def test_decode_embedded_value_long_uint_bytes_consumed(self):
         value = b'i\xff\xff\xff\xff'
-        self.assertEqual(decode._embedded_value(value)[0], 5)
+        self.assertEqual(decode.embedded_value(value)[0], 5)
 
     def test_decode_embedded_value_long_uint_data_type(self):
         value = b'i\xff\xff\xff\xff'
-        self.assertIsInstance(decode._embedded_value(value)[1], int)
+        self.assertIsInstance(decode.embedded_value(value)[1], int)
 
     def test_decode_embedded_value_long_uint_value(self):
         value = b'i\xff\xff\xff\xff'
-        self.assertEqual(decode._embedded_value(value)[1], 4294967295)
+        self.assertEqual(decode.embedded_value(value)[1], 4294967295)
 
     def test_decode_embedded_value_long_long_bytes_consumed(self):
         value = b'l\x7f\xff\xff\xff\xff\xff\xff\xf8'
-        self.assertEqual(decode._embedded_value(value)[0], 9)
+        self.assertEqual(decode.embedded_value(value)[0], 9)
 
     @unittest.skipIf(PLATFORM_32BIT, 'Skipped on 32-bit platforms')
     def test_decode_embedded_value_long_long_data_type_64bit(self):
         value = b'l\x7f\xff\xff\xff\xff\xff\xff\xf8'
-        self.assertIsInstance(decode._embedded_value(value)[1], int)
+        self.assertIsInstance(decode.embedded_value(value)[1], int)
 
     @unittest.skipIf(PLATFORM_64BIT, 'Skipped on 64-bit platforms')
     def test_decode_embedded_value_long_long_data_type_32bit(self):
         value = b'l\x7f\xff\xff\xff\xff\xff\xff\xf8'
-        self.assertIsInstance(decode._embedded_value(value)[1], long)
+        self.assertIsInstance(decode.embedded_value(value)[1], int)
 
     def test_decode_embedded_value_long_long_value(self):
         value = b'l\x7f\xff\xff\xff\xff\xff\xff\xf8'
-        self.assertEqual(decode._embedded_value(value)[1], 9223372036854775800)
+        self.assertEqual(decode.embedded_value(value)[1], 9223372036854775800)
 
     def test_decode_embedded_value_longstr_bytes_consumed(self):
         value = b'S\x00\x00\x00\n0123456789'
-        self.assertEqual(decode._embedded_value(value)[0], 15)
+        self.assertEqual(decode.embedded_value(value)[0], 15)
 
     def test_decode_embedded_value_longstr_data_type(self):
         value = b'S\x00\x00\x00\n0123456789'
-        expectation = bytes if PYTHON3 else str
-        self.assertIsInstance(decode._embedded_value(value)[1], expectation)
+        self.assertIsInstance(decode.embedded_value(value)[1], str)
 
     def test_decode_embedded_value_byte_array_data(self):
         value = b'x\x00\x00\x00\x03ABC'
         self.assertEqual(
-            decode._embedded_value(value)[1], bytearray([65, 66, 67]))
+            decode.embedded_value(value)[1], bytearray([65, 66, 67]))
 
     def test_decode_embedded_value_byte_array_data_type(self):
         value = b'x\x00\x00\x00\x03ABC'
-        self.assertIsInstance(decode._embedded_value(value)[1], bytearray)
+        self.assertIsInstance(decode.embedded_value(value)[1], bytearray)
 
     def test_decode_embedded_value_longstr_data_type_unicode(self):
         value = (b'S\x00\x00\x00\x0c\xd8\xa7\xd8\xae\xd8\xaa\xd8\xa8\xd8'
                  b'\xa7\xd8\xb1')
-        self.assertIsInstance(decode._embedded_value(value)[1], bytes)
+        self.assertIsInstance(decode.embedded_value(value)[1], str)
 
     def test_decode_embedded_value_longstr_value(self):
         value = b'S\x00\x00\x00\n0123456789'
-        self.assertEqual(decode._embedded_value(value)[1], b'0123456789')
+        self.assertEqual(decode.embedded_value(value)[1], '0123456789')
 
     def test_decode_embedded_value_short_bytes_consumed(self):
         value = b's\x7f\xff'
-        self.assertEqual(decode._embedded_value(value)[0], 3)
+        self.assertEqual(decode.embedded_value(value)[0], 3)
 
     def test_decode_embedded_value_short_short_bytes_consumed(self):
-        self.assertEqual(decode._embedded_value(b'b\xff')[0], 2)
+        self.assertEqual(decode.embedded_value(b'b\xff')[0], 2)
 
     def test_decode_embedded_value_short_short_data_type(self):
-        self.assertIsInstance(decode._embedded_value(b'b\xff')[1], int)
+        self.assertIsInstance(decode.embedded_value(b'b\xff')[1], int)
 
     def test_decode_embedded_value_short_short_value(self):
-        self.assertEqual(decode._embedded_value(b'b\xff')[1], 255)
+        self.assertEqual(decode.embedded_value(b'B\xff')[1], 255)
 
     def test_decode_embedded_value_short_data_type(self):
         value = b's\x7f\xff'
-        self.assertIsInstance(decode._embedded_value(value)[1], int)
+        self.assertIsInstance(decode.embedded_value(value)[1], int)
 
     def test_decode_embedded_value_short_value(self):
-        self.assertEqual(decode._embedded_value(b's\x7f\xff')[1], 32767)
+        self.assertEqual(decode.embedded_value(b's\x7f\xff')[1], 32767)
 
     def test_decode_embedded_value_short_uint_data_type(self):
-        self.assertIsInstance(decode._embedded_value(b'u\xff\xff')[1], int)
+        self.assertIsInstance(decode.embedded_value(b'u\xff\xff')[1], int)
 
     def test_decode_embedded_value_short_uint_value(self):
-        self.assertEqual(decode._embedded_value(b'u\xff\xff')[1], 65535)
+        self.assertEqual(decode.embedded_value(b'u\xff\xff')[1], 65535)
 
     def test_decode_embedded_value_timestamp_bytes_consumed(self):
         value = b'T\x00\x00\x00\x00Ec)\x92'
-        self.assertEqual(decode._embedded_value(value)[0], 9)
+        self.assertEqual(decode.embedded_value(value)[0], 9)
 
     def test_decode_embedded_value_timestamp_data_type(self):
         value = b'T\x00\x00\x00\x00Ec)\x92'
         self.assertIsInstance(
-            decode._embedded_value(value)[1], time.struct_time)
+            decode.embedded_value(value)[1], datetime.datetime)
 
     def test_decode_embedded_value_timestamp_value(self):
         value = b'T\x00\x00\x00\x00Ec)\x92'
         self.assertEqual(
-            decode._embedded_value(value)[1],
-            time.struct_time((2006, 11, 21, 16, 30, 10, 1, 325, 0)))
+            decode.embedded_value(value)[1],
+            datetime.datetime(2006, 11, 21, 16, 30, 10))
 
     def test_decode_embedded_value_field_array_bytes_consumed(self):
         self.assertEqual(
-            decode._embedded_value(b'A' + self.FIELD_ARR)[0],
+            decode.embedded_value(b'A' + self.FIELD_ARR)[0],
             len(b'A' + self.FIELD_ARR))
 
     def test_decode_embedded_value_field_array_data_type(self):
         self.assertIsInstance(
-            decode._embedded_value(b'A' + self.FIELD_ARR)[1], list)
+            decode.embedded_value(b'A' + self.FIELD_ARR)[1], list)
 
     def test_decode_embedded_value_field_array_value(self):
-        value = decode._embedded_value(b'A' + self.FIELD_ARR)[1]
+        value = decode.embedded_value(b'A' + self.FIELD_ARR)[1]
         for position in range(0, len(value)):
             if isinstance(value[position], float):
                 self.assertAlmostEqual(
@@ -699,15 +690,15 @@ class CodecDecodeTests(unittest.TestCase):
 
     def test_decode_embedded_value_field_table_bytes_consumed(self):
         self.assertEqual(
-            decode._embedded_value(b'F' + self.FIELD_TBL)[0],
+            decode.embedded_value(b'F' + self.FIELD_TBL)[0],
             len(b'F' + self.FIELD_TBL))
 
     def test_decode_embedded_value_field_table_data_type(self):
         self.assertIsInstance(
-            decode._embedded_value(b'F' + self.FIELD_TBL)[1], dict)
+            decode.embedded_value(b'F' + self.FIELD_TBL)[1], dict)
 
     def test_decode_embedded_value_field_table_value(self):
-        value = decode._embedded_value(b'F' + self.FIELD_TBL)[1]
+        value = decode.embedded_value(b'F' + self.FIELD_TBL)[1]
         for key in self.FIELD_TBL_VALUE.keys():
             if isinstance(value[key], float):
                 self.assertAlmostEqual(round(value[key], 3),
@@ -716,12 +707,12 @@ class CodecDecodeTests(unittest.TestCase):
                 self.assertEqual(value[key], self.FIELD_TBL_VALUE[key])
 
     def test_decode_embedded_value_void_consumed(self):
-        self.assertEqual(decode._embedded_value(b'V')[0], 1)
+        self.assertEqual(decode.embedded_value(b'V')[0], 1)
 
     def test_decode_embedded_value_void_value(self):
-        self.assertIsNone(decode._embedded_value(b'V')[1])
+        self.assertIsNone(decode.embedded_value(b'V')[1])
 
     def test_field_embedded_value_field_table_keys(self):
-        value = decode._embedded_value(b'F' + self.FIELD_TBL)[1]
+        value = decode.embedded_value(b'F' + self.FIELD_TBL)[1]
         self.assertListEqual(sorted(value.keys()),
                              sorted(self.FIELD_TBL_VALUE.keys()))
